@@ -77,6 +77,17 @@ namespace gnote {
     register_main_window_action("enable-spell-check", &Glib::Variant<bool>::variant_type());
     register_main_window_action("new-notebook", NULL, false);
     register_main_window_action("move-to-notebook", &Glib::Variant<Glib::ustring>::variant_type(), false);
+    register_main_window_action("undo", NULL, true);
+    register_main_window_action("redo", NULL, true);
+    register_main_window_action("link", NULL, true);
+    register_main_window_action("change-font-bold", &Glib::Variant<bool>::variant_type(), true);
+    register_main_window_action("change-font-italic", &Glib::Variant<bool>::variant_type(), true);
+    register_main_window_action("change-font-strikeout", &Glib::Variant<bool>::variant_type(), true);
+    register_main_window_action("change-font-highlight", &Glib::Variant<bool>::variant_type(), true);
+    register_main_window_action("change-font-size", &Glib::Variant<Glib::ustring>::variant_type(), true);
+    register_main_window_action("enable-bullets", &Glib::Variant<bool>::variant_type(), true);
+    register_main_window_action("increase-indent", NULL, true);
+    register_main_window_action("decrease-indent", NULL, true);
   }
 
 
