@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014 Aurimas Cernius
+ * Copyright (C) 2010-2016 Aurimas Cernius
  * Copyright (C) 2009, 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -36,6 +36,7 @@
 #include "addinmanager.hpp"
 #include "addinpreferencefactory.hpp"
 #include "debug.hpp"
+#include "iactionmanager.hpp"
 #include "ignote.hpp"
 #include "preferences.hpp"
 #include "preferencetabaddin.hpp"
@@ -373,6 +374,19 @@ namespace {
     }
   }
 
+  std::vector<NoteAddin*> AddinManager::get_note_addins(const Note::Ptr & note) const
+  {
+    std::vector<NoteAddin*> addins;
+    NoteAddinMap::const_iterator iter = m_note_addins.find(note);
+    if(iter != m_note_addins.end()) {
+      for(IdAddinMap::const_iterator it = iter->second.begin(); it != iter->second.end(); ++it) {
+        addins.push_back(it->second);
+      }
+    }
+
+    return addins;
+  }
+
   ApplicationAddin * AddinManager::get_application_addin(
                                      const std::string & id) const
   {
@@ -420,6 +434,7 @@ namespace {
 
   void AddinManager::initialize_application_addins() const
   {
+    register_addin_actions();
     for(AppAddinMap::const_iterator iter = m_app_addins.begin();
         iter != m_app_addins.end(); ++iter) {
       ApplicationAddin * addin = iter->second;
@@ -563,4 +578,16 @@ namespace {
     SETUP_NOTE_ADDIN(key, Preferences::ENABLE_AUTO_LINKS, NoteLinkWatcher);
     SETUP_NOTE_ADDIN(key, Preferences::ENABLE_WIKIWORDS, NoteWikiWatcher);
   }
+
+  void AddinManager::register_addin_actions() const
+  {
+    auto & manager(IActionManager::obj());
+    for(auto & info : m_addin_infos) {
+      auto & non_modifying = info.second.non_modifying_actions();
+      for(auto & action : info.second.actions()) {
+        manager.register_main_window_action(action.first, action.second,
+          std::find(non_modifying.begin(), non_modifying.end(), action.first) == non_modifying.end());
+      }
+    }
+  }
 }
