@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010,2013 Aurimas Cernius
+ * Copyright (C) 2010,2013,2016 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,9 +25,6 @@
 #ifndef __INSERTIMESTAMP_NOTEADDIN_HPP_
 #define __INSERTIMESTAMP_NOTEADDIN_HPP_
 
-#include <gtkmm/menuitem.h>
-
-#include "base/macros.hpp"
 #include "sharp/dynamicmodule.hpp"
 #include "noteaddin.hpp"
 
@@ -55,8 +52,9 @@ public:
   virtual void initialize() override;
   virtual void shutdown() override;
   virtual void on_note_opened() override;
+  virtual std::map<int, Gtk::Widget*> get_actions_popover_widgets() const override;
 private:
-  void on_menu_item_activated();
+  void on_menu_item_activated(const Glib::VariantBase&);
   void on_format_setting_changed(const Glib::ustring & key);
 
   std::string    m_date_format;
