@@ -319,6 +319,17 @@ namespace gnote {
     {
       widget.property_margin_top() = 5;
       widget.property_margin_bottom() = 5;
+      widget.property_hexpand() = true;
+    }
+
+    Gtk::Grid *create_popover_inner_grid(int *top)
+    {
+      Gtk::Grid *grid = new Gtk::Grid;
+      set_common_popover_widget_props(*grid);
+      if(top) {
+        *top = 0;
+      }
+      return grid;
     }
 
 
